@@ -4,14 +4,15 @@
 #include <stdio.h>
 #include <math.h>
 #include <minpack.h>
+#define real __minpack_real__
 
-void fcn(const int *n, const double *x, double *fvec, int *iflag);
+void fcn(const int *n, const real *x, real *fvec, int *iflag);
 
 int main()
 {
   int j, n, info, lwa;
-  double tol, fnorm;
-  double x[9], fvec[9], wa[180];
+  real tol, fnorm;
+  real x[9], fvec[9], wa[180];
   int one=1;
 
   n = 9;
@@ -29,25 +30,25 @@ int main()
 /*      unless high solutions are required, */
 /*      this is the recommended setting. */
 
-  tol = sqrt(dpmpar_(&one));
-  hybrd1_(&fcn, &n, x, fvec, &tol, &info, wa, &lwa);
-  fnorm = enorm_(&n, fvec);
+  tol = sqrt(__minpack_func__(dpmpar)(&one));
+  __minpack_func__(hybrd1)(&fcn, &n, x, fvec, &tol, &info, wa, &lwa);
+  fnorm = __minpack_func__(enorm)(&n, fvec);
 
-  printf("     final L2 norm of the residuals %15.7g\n", fnorm);
+  printf("     final L2 norm of the residuals %15.7g\n", (double)fnorm);
   printf("     exit parameter                 %10i\n", info);
   printf("     final approximates solution\n");
-  for (j=1; j<=n; j++) printf("%s%15.7g",j%3==1?"\n     ":"", x[j-1]);
+  for (j=1; j<=n; j++) printf("%s%15.7g",j%3==1?"\n     ":"", (double)x[j-1]);
   printf("\n");
 
   return 0;
 }
 
-void fcn(const int *n, const double *x, double *fvec, int *iflag)
+void fcn(const int *n, const real *x, real *fvec, int *iflag)
 {
 /*      subroutine fcn for hybrd1 example. */
 
   int k;
-  double one=1, temp, temp1, temp2, three=3, two=2, zero=0;
+  real one=1, temp, temp1, temp2, three=3, two=2, zero=0;
 
   for (k=1; k <= *n; k++)
     {
