@@ -3,20 +3,22 @@
 	-lf2c -lm   (in that order)
 */
 
-#include <math.h>
 #include "minpack.h"
+#include <math.h>
+#define real __minpack_real__
+
 #define min(a,b) ((a) <= (b) ? (a) : (b))
 #define max(a,b) ((a) >= (b) ? (a) : (b))
 #define TRUE_ (1)
 #define FALSE_ (0)
 
-/* Subroutine */ void lmdif_(void (*fcn)(const int *m, const int *n, const double *x, double *fvec,
-			  int *iflag ), const int *m, const int *n, double *x, 
-	double *fvec, const double *ftol, const double *xtol, const double *
-	gtol, const int *maxfev, const double *epsfcn, double *diag, const int *
-	mode, const double *factor, const int *nprint, int *info, int *
-	nfev, double *fjac, const int *ldfjac, int *ipvt, double *
-	qtf, double *wa1, double *wa2, double *wa3, double *
+__minpack_attr__
+void __minpack_func__(lmdif)(__minpack_decl_fcn_mn__ const int *m, const int *n, real *x, 
+	real *fvec, const real *ftol, const real *xtol, const real *
+	gtol, const int *maxfev, const real *epsfcn, real *diag, const int *
+	mode, const real *factor, const int *nprint, int *info, int *
+	nfev, real *fjac, const int *ldfjac, int *ipvt, real *
+	qtf, real *wa1, real *wa2, real *wa3, real *
 	wa4)
 {
     /* Table of constant values */
@@ -34,18 +36,18 @@
 
     /* System generated locals */
     int fjac_dim1, fjac_offset, i__1, i__2;
-    double d__1, d__2, d__3;
+    real d__1, d__2, d__3;
 
     /* Local variables */
     int i__, j, l;
-    double par, sum;
+    real par, sum;
     int iter;
-    double temp, temp1, temp2;
+    real temp, temp1, temp2;
     int iflag;
-    double delta;
-    double ratio;
-    double fnorm, gnorm;
-    double pnorm, xnorm, fnorm1, actred, dirder, epsmch, prered;
+    real delta;
+    real ratio;
+    real fnorm, gnorm;
+    real pnorm, xnorm, fnorm1, actred, dirder, epsmch, prered;
 
 /*     ********** */
 
@@ -245,7 +247,7 @@
 
 /*     epsmch is the machine precision. */
 
-    epsmch = dpmpar_(&c__1);
+    epsmch = __minpack_func__(dpmpar)(&c__1);
 
     *info = 0;
     iflag = 0;
@@ -273,12 +275,12 @@ L20:
 /*     and calculate its norm. */
 
     iflag = 1;
-    (*fcn)(m, n, &x[1], &fvec[1], &iflag);
+    fcn_mn(m, n, &x[1], &fvec[1], &iflag);
     *nfev = 1;
     if (iflag < 0) {
 	goto L300;
     }
-    fnorm = enorm_(m, &fvec[1]);
+    fnorm = __minpack_func__(enorm)(m, &fvec[1]);
 
 /*     initialize levenberg-marquardt parameter and iteration counter. */
 
@@ -292,7 +294,7 @@ L30:
 /*        calculate the jacobian matrix. */
 
     iflag = 2;
-    fdjac2_(fcn, m, n, &x[1], &fvec[1], &fjac[fjac_offset], ldfjac, &
+    __minpack_func__(fdjac2)(__minpack_param_fcn_mn__ m, n, &x[1], &fvec[1], &fjac[fjac_offset], ldfjac, &
 	    iflag, epsfcn, &wa4[1]);
     *nfev += *n;
     if (iflag < 0) {
@@ -306,7 +308,7 @@ L30:
     }
     iflag = 0;
     if ((iter - 1) % *nprint == 0) {
-	(*fcn)(m, n, &x[1], &fvec[1], &iflag);
+	fcn_mn(m, n, &x[1], &fvec[1], &iflag);
     }
     if (iflag < 0) {
 	goto L300;
@@ -315,7 +317,7 @@ L40:
 
 /*        compute the qr factorization of the jacobian. */
 
-    qrfac_(m, n, &fjac[fjac_offset], ldfjac, &c_true, &ipvt[1], n, &wa1[1], &
+    __minpack_func__(qrfac)(m, n, &fjac[fjac_offset], ldfjac, &c_true, &ipvt[1], n, &wa1[1], &
 	    wa2[1], &wa3[1]);
 
 /*        on the first iteration and if mode is 1, scale according */
@@ -345,7 +347,7 @@ L60:
 	wa3[j] = diag[j] * x[j];
 /* L70: */
     }
-    xnorm = enorm_(n, &wa3[1]);
+    xnorm = __minpack_func__(enorm)(n, &wa3[1]);
     delta = *factor * xnorm;
     if (delta == 0.) {
 	delta = *factor;
@@ -439,7 +441,7 @@ L200:
 
 /*           determine the levenberg-marquardt parameter. */
 
-    lmpar_(n, &fjac[fjac_offset], ldfjac, &ipvt[1], &diag[1], &qtf[1], &delta,
+    __minpack_func__(lmpar)(n, &fjac[fjac_offset], ldfjac, &ipvt[1], &diag[1], &qtf[1], &delta,
 	     &par, &wa1[1], &wa2[1], &wa3[1], &wa4[1]);
 
 /*           store the direction p and x + p. calculate the norm of p. */
@@ -451,7 +453,7 @@ L200:
 	wa3[j] = diag[j] * wa1[j];
 /* L210: */
     }
-    pnorm = enorm_(n, &wa3[1]);
+    pnorm = __minpack_func__(enorm)(n, &wa3[1]);
 
 /*           on the first iteration, adjust the initial step bound. */
 
@@ -462,12 +464,12 @@ L200:
 /*           evaluate the function at x + p and calculate its norm. */
 
     iflag = 1;
-    (*fcn)(m, n, &wa2[1], &wa4[1], &iflag);
+    fcn_mn(m, n, &wa2[1], &wa4[1], &iflag);
     ++(*nfev);
     if (iflag < 0) {
 	goto L300;
     }
-    fnorm1 = enorm_(m, &wa4[1]);
+    fnorm1 = __minpack_func__(enorm)(m, &wa4[1]);
 
 /*           compute the scaled actual reduction. */
 
@@ -493,7 +495,7 @@ L200:
 	}
 /* L230: */
     }
-    temp1 = enorm_(n, &wa3[1]) / fnorm;
+    temp1 = __minpack_func__(enorm)(n, &wa3[1]) / fnorm;
     temp2 = sqrt(par) * pnorm / fnorm;
 /* Computing 2nd power */
     d__1 = temp1;
@@ -561,7 +563,7 @@ L260:
 	fvec[i__] = wa4[i__];
 /* L280: */
     }
-    xnorm = enorm_(n, &wa2[1]);
+    xnorm = __minpack_func__(enorm)(n, &wa2[1]);
     fnorm = fnorm1;
     ++iter;
 L290:
@@ -618,7 +620,7 @@ L300:
     }
     iflag = 0;
     if (*nprint > 0) {
-	(*fcn)(m, n, &x[1], &fvec[1], &iflag);
+	fcn_mn(m, n, &x[1], &fvec[1], &iflag);
     }
     return;
 
